@@ -1,4 +1,5 @@
 from .. import utils
+from .stats import KillsDeaths, FinalKillsDeaths, WinsLosses
 
 
 class Bedwars:
@@ -59,37 +60,6 @@ class BedsBrokenLost:
     def increase(self, *, amount: int = 0):
         return utils.get_increase(self.broken, self.lost, amount=amount)
 
-
-class KillsDeaths:
-    def __init__(self, kills, deaths):
-        self.kills = kills
-        self.deaths = deaths
-        self.ratio = utils.get_ratio(kills, deaths)
-
-    def increase(self, *, amount: int = 0):
-        return utils.get_increase(self.kills, self.deaths, amount=amount)
-
-
-class FinalKillsDeaths:
-    def __init__(self, kills, deaths):
-        self.kills = kills
-        self.deaths = deaths
-        self.ratio = utils.get_ratio(kills, deaths)
-
-    def increase(self, *, amount: int = 0):
-        return utils.get_increase(self.kills, self.deaths, amount=amount)
-
-
-class WinsLosses:
-    def __init__(self, wins, losses):
-        self.wins = wins
-        self.losses = losses
-        self.ratio = utils.get_ratio(wins, losses)
-
-    def increase(self, *, amount: int = 0):
-        return utils.get_increase(self.wins, self.losses, amount=amount)
-
-
 # regular modes
 class Solo:
     def __init__(self, data):
